/* Copyright (c) 1997, MpegTV LLC */
#ifndef _msg_h
#define _msg_h
#ifndef lint
static char rcsid_msg_h[] = "$Header: /net/hopkins/var/home/tristan/mpeg/dec/RCS/msg.h,v 1.14 1997/11/29 09:07:31 tristan Exp $";
#endif

/*
 * Disclaimer of Warranty
 *
 * These software programs are available to the user without any license fee or
 * royalty on an "as is" basis.  Copyright-holder disclaims
 * any and all warranties, whether express, implied, or statuary, including any
 * implied warranties or merchantability or of fitness for a particular
 * purpose.  In no event shall the copyright-holder be liable for any
 * incidental, punitive, or consequential damages of any kind whatsoever
 * arising from the use of these programs.
 *
 * This disclaimer of warranty extends to the user of these programs and user's
 * customers, employees, agents, transferees, successors, and assigns.
 *
 */

#include "misc.h"
#include "exit.h"

/*--------------------------------------------------------------------------+
| Macros																	|
+--------------------------------------------------------------------------*/
/*
 * Print message if specified message type is selected in Msg_select
 */
#define MSG(type, message) STMT( \
	if (Msg_select & (type)) { \
		_msg_header("", __FILE__, __LINE__); \
		printf message; \
		printf("\n"); \
	} \
)

/*
 * Print message and error diagnotic if specified message type is selected in Msg_select
 */
#define MSG_ERROR(type, message) STMT( \
	if (Msg_select & (MSG_ERR|(type))) { \
		int	_msg_errno = errno; \
		_msg_header("error: ", __FILE__, __LINE__); \
		printf message; \
		printf(": %s\n", strerror(_msg_errno)); \
		errno = _msg_errno; \
	} \
)

/*
 * Print info message
 */
#define MESSAGE(message) 	MSG(MSG_INFO, message)

/*
 * Print error message
 */
#define MESSAGE_ERROR(message) 	MSG_ERROR(MSG_ERR, message)

/*
 * Print warning message
 */
#define WARNING(printf_param)	STMT( \
		if (Msg_select & MSG_WARNING) { \
			_msg_header("warning: ", __FILE__, __LINE__); \
			printf printf_param; \
			printf("\n"); \
		} \
	)


/*
 * Print message then exit
 */
#define FATAL(printf_param)	STMT( \
		_msg_header("error: ", __FILE__, __LINE__); \
		printf printf_param; \
		printf("\n"); \
		EXIT(EXIT_FAILURE); \
	)

/*
 * Print message and error diagnotic then exit
 */
#define FATAL_ERROR(printf_param)	STMT( \
		int	_msg_errno = errno; \
		_msg_header("error: ", __FILE__, __LINE__); \
		printf printf_param; \
		printf(": %s\n", strerror(_msg_errno)); \
		EXIT(EXIT_FAILURE); \
	)

/*--------------------------------------------------------------------------+
| Data types																|
+--------------------------------------------------------------------------*/

/* Masks used in Msg_select. Msg_select is a bitwise OR of those flags */

#define	MSG_INFO		(1 << 0)	/* for MESSAGE() */
#define	MSG_ERR			(1 << 1)	/* for ERROR() i.e. non-fatal errors */
#define	MSG_WARNING		(1 << 2)	/* for WARNING() */

/* the following are used to select specific messages frpm the player */
#define	MSG_SYNC		(1 << 3)	/* framerate sync messages */
#define	MSG_PTS			(1 << 4)	/* audio / PTS messages */
#define	MSG_PMP			(1 << 5)	/* process communication messages */
#define	MSG_READ		(1 << 6)	/* input stream read messages */
#define	MSG_SYS			(1 << 7)	/* systems parsing messages */
#define	MSG_X			(1 << 8)	/* Xlib */

#define	MSG_AUDIO_SYNC	(1 << 8)	/* audio sync */
#define	MSG_AUDIO_IOCTL	(1 << 9)	/* audio ioctl */
#define	MSG_AUDIO_WRITE	(1 << 10)	/* audio write samples */

/*--------------------------------------------------------------------------+
| Externals																	|
+--------------------------------------------------------------------------*/

extern u_long Msg_select;
extern const char *Msg_progname;

#ifdef __cplusplus
extern "C" {
#endif

extern const char * _msg_filename(const char *);
extern void _msg_header(const char *, const char *, int);
#ifndef _msg_c
extern const char * (*Msg_info_func)(void);
#endif

#ifdef __cplusplus
}
#endif


#endif /* _msg_h */
